@@ -455,7 +455,8 @@ enum class DescriptorType_t {
     OPERATION_RNG_DESCRIPTOR,
     OPERATION_PAGED_CACHE_LOAD_DESCRIPTOR,
     OPERATION_BLOCK_SCALE_QUANTIZE_DESCRIPTOR,
-    OPERATION_BLOCK_SCALE_DEQUANTIZE_DESCRIPTOR
+    OPERATION_BLOCK_SCALE_DEQUANTIZE_DESCRIPTOR,
+    OPERATION_CONCATENATE_DESCRIPTOR
 };
 
 enum class NormMode_t {
@@ -466,6 +467,7 @@ enum class NormMode_t {
     BATCH_NORM,
     GROUP_NORM,
     RMS_NORM,
+    ADA_LAYER_NORM,
 };
 
 NLOHMANN_JSON_SERIALIZE_ENUM(NormMode_t,
@@ -476,6 +478,7 @@ NLOHMANN_JSON_SERIALIZE_ENUM(NormMode_t,
                                  {NormMode_t::BATCH_NORM, "BATCH_NORM"},
                                  {NormMode_t::GROUP_NORM, "GROUP_NORM"},
                                  {NormMode_t::RMS_NORM, "RMS_NORM"},
+                                 {NormMode_t::ADA_LAYER_NORM, "ADA_LAYER_NORM"},
                              })
 
 enum class PointwiseMode_t {
@@ -916,6 +919,9 @@ operator<<(std::ostream& os, const DescriptorType_t& mode) {
         case DescriptorType_t::OPERATION_BLOCK_SCALE_DEQUANTIZE_DESCRIPTOR:
             os << "OPERATION_BLOCK_SCALE_DEQUANTIZE_DESCRIPTOR";
             break;
+        case DescriptorType_t::OPERATION_CONCATENATE_DESCRIPTOR:
+            os << "OPERATION_CONCATENATE_DESCRIPTOR";
+            break;
         case DescriptorType_t::NOT_SET:
             os << "NOT_SET";
             break;
@@ -1571,6 +1577,14 @@ convert_to_cudnn_type(cudnn_frontend::DescriptorType_t const mode, cudnnBackendD
 #else
             return cudnnStatus_t::CUDNN_STATUS_INVALID_VALUE;
 #endif
+        case DescriptorType_t::OPERATION_CONCATENATE_DESCRIPTOR:
+#if (CUDNN_VERSION >= 90700)
+            NV_CUDNN_FE_DYNAMIC_CHECK_CUDNN_BACKEND_VERSION(90700, cudnnStatus_t::CUDNN_STATUS_INVALID_VALUE);
+            cudnn_mode = CUDNN_BACKEND_OPERATION_CONCAT_DESCRIPTOR;
+            return cudnnStatus_t::CUDNN_STATUS_SUCCESS;
+#else
+            return cudnnStatus_t::CUDNN_STATUS_INVALID_VALUE;
+#endif
 
 #ifndef NO_DEFAULT_IN_SWITCH
         default:
@@ -1654,7 +1668,12 @@ convert_to_cudnn_type(cudnn_frontend::NormMode_t const mode, cudnnBackendNormMod
             cudnn_mode = CUDNN_RMS_NORM;
             return cudnnStatus_t::CUDNN_STATUS_SUCCESS;
 #endif
-
+#if (CUDNN_VERSION >= 90900)
+        case NormMode_t::ADA_LAYER_NORM:
+            NV_CUDNN_FE_DYNAMIC_CHECK_CUDNN_BACKEND_VERSION(90900, cudnnStatus_t::CUDNN_STATUS_INVALID_VALUE);
+            cudnn_mode = CUDNN_ADA_LAYER_NORM;
+            return cudnnStatus_t::CUDNN_STATUS_SUCCESS;
+#endif
 #ifndef NO_DEFAULT_IN_SWITCH
         default:
             return cudnnStatus_t::CUDNN_STATUS_INVALID_VALUE;
