@@ -156,6 +156,24 @@ class PyGraph {
                        cudnn_frontend::DataType_t const& compute_data_type,
                        std::string const& name);
 
+    std::vector<std::shared_ptr<cudnn_frontend::graph::Tensor_attributes>>
+    adalayernorm(cudnn_frontend::NormFwdPhase_t const forward_phase,
+                 std::shared_ptr<cudnn_frontend::graph::Tensor_attributes>& x,
+                 std::shared_ptr<cudnn_frontend::graph::Tensor_attributes>& scale,
+                 std::shared_ptr<cudnn_frontend::graph::Tensor_attributes>& bias,
+                 std::shared_ptr<cudnn_frontend::graph::Tensor_attributes>& epsilon,
+                 cudnn_frontend::DataType_t const& compute_data_type,
+                 std::string const& name);
+
+    std::vector<std::shared_ptr<cudnn_frontend::graph::Tensor_attributes>>
+    adalayernorm_backward(std::shared_ptr<cudnn_frontend::graph::Tensor_attributes> const& dy,
+                          std::shared_ptr<cudnn_frontend::graph::Tensor_attributes> const& x,
+                          std::shared_ptr<cudnn_frontend::graph::Tensor_attributes> const& scale,
+                          std::shared_ptr<cudnn_frontend::graph::Tensor_attributes> const& mean,
+                          std::shared_ptr<cudnn_frontend::graph::Tensor_attributes> const& inv_variance,
+                          cudnn_frontend::DataType_t const& compute_data_type,
+                          std::string const& name);
+
     std::vector<std::shared_ptr<cudnn_frontend::graph::Tensor_attributes>>
     batchnorm_backward(std::shared_ptr<cudnn_frontend::graph::Tensor_attributes> const& dy,
                        std::shared_ptr<cudnn_frontend::graph::Tensor_attributes> const& x,
