@@ -80,7 +80,7 @@ TEST_CASE("Convolution fprop", "[conv][graph][caching]") {
     std::unordered_map<int64_t, void *> variant_pack = {
         {X->get_uid(), x_tensor.devPtr}, {W->get_uid(), w_tensor.devPtr}, {Y->get_uid(), y_tensor.devPtr}};
 
-    int64_t workspace_size;
+    int64_t workspace_size = 0;
     REQUIRE(graph->get_workspace_size(workspace_size).is_good());
     Surface<int8_t> workspace(workspace_size, false);
 
@@ -302,7 +302,7 @@ TEST_CASE("CSBR Graph", "[conv][graph][caching]") {
     Surface<half> b_tensor(k, false);
     Surface<half> y_tensor(n * k * h * w, false);  // Should be p, q.
 
-    int64_t workspace_size;
+    int64_t workspace_size = 0;
     REQUIRE(graph->get_workspace_size(workspace_size).is_good());
     Surface<int8_t> workspace(workspace_size, false);
 
@@ -546,7 +546,7 @@ TEST_CASE("SBRCS", "[conv][genstats][graph]") {
         {SUM, sum_tensor.devPtr},
         {SQ_SUM, sq_sum_tensor.devPtr}};
 
-    int64_t workspace_size;
+    int64_t workspace_size = 0;
     REQUIRE(graph->get_workspace_size(workspace_size).is_good());
     Surface<int8_t> workspace(workspace_size, false);
 
@@ -647,7 +647,7 @@ TEST_CASE("CBR Graph NCHW", "[conv][graph][caching]") {
     Surface<half> y_tensor(n * k * h * w, false);  // Should be p, q.
     Surface<half> z_tensor(n * k * h * w, false);  // Should be p, q.
 
-    int64_t workspace_size;
+    int64_t workspace_size = 0;
     REQUIRE(graph->get_workspace_size(workspace_size).is_good());
     Surface<int8_t> workspace(workspace_size, false);
 
@@ -728,7 +728,7 @@ TEST_CASE("Convolution fprop large", "[conv][graph][caching]") {
     std::unordered_map<int64_t, void *> variant_pack = {
         {X->get_uid(), x_tensor.devPtr}, {W->get_uid(), w_tensor.devPtr}, {Y->get_uid(), y_tensor.devPtr}};
 
-    int64_t workspace_size;
+    int64_t workspace_size = 0;
     REQUIRE(graph->get_workspace_size(workspace_size).is_good());
     Surface<int8_t> workspace(workspace_size, false);
 
@@ -820,7 +820,7 @@ TEST_CASE("Convolution fprop concatenate", "[conv][graph][caching]") {
                                                         {Y0->get_uid(), y0_tensor.devPtr},
                                                         {Y1->get_uid(), y1_tensor.devPtr}};
 
-    int64_t workspace_size;
+    int64_t workspace_size = 0;
     REQUIRE(graph->get_workspace_size(workspace_size).is_good());
     Surface<int8_t> workspace(workspace_size, false);
 
