@@ -259,7 +259,7 @@ TEST_CASE("Toy sdpa forward with paged caches", "[graph][sdpa][flash][paged][for
             auto benchmark = [&]() -> bool {
                 const int iter_count = 1000;
 
-                int64_t workspace_size;
+                int64_t workspace_size = 0;
                 REQUIRE(graph->get_workspace_size(workspace_size).is_good());
                 Surface<int8_t> workspace(workspace_size, false);
 
